@@ -1,6 +1,6 @@
 ;;; geiser-connection.el --- Talking to a scheme process  -*- lexical-binding: t; -*-
 
-;; Copyright (C) 2009-2011, 2013, 2021-2022 Jose Antonio Ortega Ruiz
+;; Copyright (C) 2009-2011, 2013, 2021-2022, 2025 Jose Antonio Ortega Ruiz
 
 ;; This program is free software; you can redistribute it and/or
 ;; modify it under the terms of the Modified BSD License. You should
@@ -87,7 +87,7 @@
           (unwind-protect
               (funcall (tq-queue-head-fn tq)
                        (tq-queue-head-closure tq)
-                       (buffer-substring (point-min) (match-beginning 0)))
+                       (buffer-substring (point-min) (point)))
             (delete-region (point-min) (point-max))
             (tq-queue-pop tq)))))))
 
@@ -139,7 +139,7 @@
 
 (defun geiser-con--connection-update-debugging (c txt)
   (let* ((dp (geiser-con--connection-debug-prompt c))
-         (is-d (and (stringp dp) (string-match dp txt))))
+         (is-d (and (stringp dp) (string-match-p dp txt))))
     (geiser-con--connection-set-debugging c is-d)
     is-d))
 
