@@ -1,6 +1,6 @@
 ;;; geiser.el --- GNU Emacs and Scheme talk to each other -*- lexical-binding: t; -*-
 
-;; Copyright (C) 2009-2013, 2015, 2018, 2021-2024 Jose Antonio Ortega Ruiz
+;; Copyright (C) 2009-2013, 2015, 2018, 2021-2025 Jose Antonio Ortega Ruiz
 
 ;; This program is free software; you can redistribute it and/or
 ;; modify it under the terms of the Modified BSD License. You should
@@ -13,7 +13,7 @@
 ;; Homepage: https://gitlab.com/emacs-geiser/
 ;; Package-Requires: ((emacs "27.1") (project "0.8.1"))
 ;; SPDX-License-Identifier: BSD-3-Clause
-;; Version: 0.31.1
+;; Version: 0.32
 
 ;;; Commentary:
 
@@ -51,12 +51,53 @@
 
 
 ;;; Code:
+;;; Locations:
 
 ;;;###autoload
 (defconst geiser-elisp-dir
   (file-name-directory (or load-file-name buffer-file-name))
   "Directory containing Geiser's Elisp files.")
 
+
+;;; Autoloads:
+
+;;;###autoload
+(autoload 'geiser-unload "geiser-reload" "Unload all Geiser code." t)
+
+;;;###autoload
+(autoload 'geiser-reload "geiser-reload" "Reload Geiser code." t)
+
+;;;###autoload
+(autoload 'geiser "geiser-repl" "Start a Geiser REPL." t)
+
+;;;###autoload
+(autoload 'run-geiser "geiser-repl" "Start a Geiser REPL." t)
+
+;;;###autoload
+(autoload 'geiser-connect "geiser-repl"
+  "Start a Geiser REPL connected to a remote server." t)
+
+;;;###autoload
+(autoload 'geiser-connect-local "geiser-repl"
+  "Start a Geiser REPL connected to a remote server over a Unix-domain socket."
+  t)
+
+;;;###autoload
+(autoload 'geiser-repl-switch "geiser-repl"
+  "Switch to a running one Geiser REPL." t)
+
+;;;###autoload
+(autoload 'geiser-mode "geiser-mode"
+  "Minor mode adding Geiser REPL interaction to Scheme buffers." t)
+
+;;;###autoload
+(autoload 'turn-on-geiser-mode "geiser-mode"
+  "Enable Geiser's mode (useful in Scheme buffers)." t)
+
+;;;###autoload
+(autoload 'turn-off-geiser-mode "geiser-mode"
+  "Disable Geiser's mode (useful in Scheme buffers)." t)
+
 (autoload 'geiser-activate-implementation "geiser-impl"
   "Register the given implementation as active.")
 
@@ -79,5 +120,14 @@
         geiser-implementation
         geiser-xref))
 
+
+;;; Setup:
+
+;;;###autoload
+(autoload 'geiser-mode--maybe-activate "geiser-mode")
+
+;;;###autoload
+(add-hook 'scheme-mode-hook #'geiser-mode--maybe-activate)
+
 (provide 'geiser)
 ;;; geiser.el ends here
